==> _private_core_network-1.3.11.tar.gz: lib/network_resources/common/common_repo.dart <==
import 'dart:collection';

import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:_private_core_network/utils.dart';
import 'app_api.dart';
import 'models/contact_form_fields.dart';
import 'models/platform_user_detail.dart';
import 'models/platform_user_list.dart';

class CommonRepo {
  CommonRepo._();

  static CommonRepo? _instance;

  factory CommonRepo([MyAppApi? api]) {
    _instance ??= CommonRepo._();
    _instance!._api = api ?? MyAppApiImp();
    return _instance!;
  }

  late MyAppApi _api;

  Map<String, dynamic> _mapParms([Map? value]) {
    Map<String, dynamic> params = {};
    if (value != null && value.isNotEmpty) params.addAll(HashMap.from(value));
    params
      ..removeWhere((key, value) => value == null)
      ..addAll({
        'platformId': valuePlatformByConfig(),
        'languageCode': appPrefs.languageCode,
      });
    return params;
  }

  Future<bool> trackOnClick(params) async {
    NetworkResponse response = await _api.trackOnClick(_mapParms(params));
    return response.data ?? false;
  }

  Future<PlatformUserList?> getPlatformsUsersFromAdmin(params) async {
    NetworkResponse response =
        await _api.getPlatformsUsersFromAdmin(_mapParms(params));
    return response.data;
  }

  Future<PlatformUserDetail?> getPlatformsUserDetailsFromAdmin(params) async {
    NetworkResponse response =
        await _api.getPlatformsUserDetailsFromAdmin(_mapParms(params));
    return response.data;
  }

  Future<List<ContactFormField>> getForms([params]) async {
    NetworkResponse response = await _api.getForms(_mapParms(params));
    return response.data;
  }

  Future<bool> fillForm(params) async {
    NetworkResponse response = await _api.fillForm(_mapParms(params));
    return response.data ?? false;
  }

  Future<List<CommonMedia>> getMediasByFilter(params) async {
    NetworkResponse response = await _api.getMediasByFilter(_mapParms(params));
    return response.data ?? [];
  }

  Future<List<CommonMedia>> getMediaByPurpose(params) async {
    NetworkResponse response = await _api.getMediaByPurpose(_mapParms(params));
    return response.data ?? [];
  }

  Future<List<CommonMedia>> getMediaCat([params]) async {
    NetworkResponse response = await _api.getMediaCat(_mapParms(params));
    return response.data ?? [];
  }

  Future<CommonMedia?> uploadMedia(
      bytes, filePath, Map<String, dynamic> params) async {
    NetworkResponse response = await _api.uploadMedia(bytes, filePath, params);
    return response.data;
  }

  Future<CommonMedia?> createMediaCat(params) async {
    NetworkResponse response = await _api.createMediaCat(_mapParms(params));
    return response.data;
  }

  Future<CommonMedia?> updateMediaCat(params) async {
    NetworkResponse response = await _api.updateMediaCat(_mapParms(params));
    return response.data;
  }

  Future<CommonMedia?> updateMedia(
      bytes, filePath, Map<String, dynamic> params) async {
    NetworkResponse response = await _api.updateMedia(bytes, filePath, params);
    return response.data;
  }

  Future<bool> deleteMedia(params) async {
    NetworkResponse response = await _api.deleteMedia(_mapParms(params));
    return response.data ?? false;
  }

  Future<bool> deleteMediaCat(params) async {
    NetworkResponse response = await _api.deleteMediaCat(_mapParms(params));
    return response.data ?? false;
  }

  Future<String?> getCountryCodeFromLatLng(params) async {
    NetworkResponse response =
        await _api.getCountryCodeFromLatLng(_mapParms(params));
    return response.data;
  }
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/common/common_repo.dart <==

import 'package:_private_core_network/network_resources/resources.dart';
import 'app_api.dart';
import 'models/contact_form_fields.dart';
import 'models/platform_user_detail.dart';
import 'models/platform_user_list.dart';

class CommonRepo {
  CommonRepo._();

  static CommonRepo? _instance;

  factory CommonRepo([MyAppApi? api]) {
    _instance ??= CommonRepo._();
    _instance!._api = api ?? MyAppApiImp();
    return _instance!;
  }

  late MyAppApi _api;

  Future<bool> trackOnClick(params) async {
    NetworkResponse response = await _api.trackOnClick(params);
    return response.data ?? false;
  }

  Future<PlatformUserList?> getPlatformsUsersFromAdmin(params) async {
    NetworkResponse response = await _api.getPlatformsUsersFromAdmin(params);
    return response.data;
  }

  Future<PlatformUserDetail?> getPlatformsUserDetailsFromAdmin(params) async {
    NetworkResponse response =
        await _api.getPlatformsUserDetailsFromAdmin(params);
    return response.data;
  }

  Future<List<ContactFormField>> getForms([params]) async {
    NetworkResponse response = await _api.getForms(params);
    return response.data;
  }

  Future<bool> fillForm(params) async {
    NetworkResponse response = await _api.fillForm(params);
    return response.data ?? false;
  }

  Future<List<CommonMedia>> getMediasByFilter(params) async {
    NetworkResponse response = await _api.getMediasByFilter(params);
    return response.data ?? [];
  }

  Future<List<CommonMedia>> getMediaByPurpose(params) async {
    NetworkResponse response = await _api.getMediaByPurpose(params);
    return response.data ?? [];
  }

  Future<List<CommonMedia>> getMediaCat([params]) async {
    NetworkResponse response = await _api.getMediaCat(params);
    return response.data ?? [];
  }

  Future<CommonMedia?> uploadMedia(
      bytes, filePath, Map<String, dynamic> params) async {
    NetworkResponse response = await _api.uploadMedia(bytes, filePath, params);
    return response.data;
  }

  Future<CommonMedia?> createMediaCat(params) async {
    NetworkResponse response = await _api.createMediaCat(params);
    return response.data;
  }

  Future<CommonMedia?> updateMediaCat(params) async {
    NetworkResponse response = await _api.updateMediaCat(params);
    return response.data;
  }

  Future<CommonMedia?> updateMedia(
      bytes, filePath, Map<String, dynamic> params) async {
    NetworkResponse response = await _api.updateMedia(bytes, filePath, params);
    return response.data;
  }

  Future<bool> deleteMedia(params) async {
    NetworkResponse response = await _api.deleteMedia(params);
    return response.data ?? false;
  }

  Future<bool> deleteMediaCat(params) async {
    NetworkResponse response = await _api.deleteMediaCat(params);
    return response.data ?? false;
  }

  Future<String?> getCountryCodeFromLatLng(params) async {
    NetworkResponse response = await _api.getCountryCodeFromLatLng(params);
    return response.data;
  }
}
